@@ -64,7 +64,7 @@ GType  bd_nvdimm_namespace_info_get_type () {
 }
 
 static gboolean  bd_nvdimm_is_tech_avail_stub (BDNVDIMMTech tech G_GNUC_UNUSED, guint64 mode G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvdimm_is_tech_avail' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvdimm_is_tech_avail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvdimm_is_tech_avail' called, but not implemented!");
     return FALSE;
@@ -87,7 +87,7 @@ gboolean  bd_nvdimm_is_tech_avail (BDNVDIMMTech tech, guint64 mode, GError **err
 
 
 static BDNVDIMMNamespaceMode  bd_nvdimm_namespace_get_mode_from_str_stub (const gchar *mode_str G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvdimm_namespace_get_mode_from_str' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvdimm_namespace_get_mode_from_str' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvdimm_namespace_get_mode_from_str' called, but not implemented!");
     return 0;
@@ -110,7 +110,7 @@ BDNVDIMMNamespaceMode  bd_nvdimm_namespace_get_mode_from_str (const gchar *mode_
 
 
 static const gchar* bd_nvdimm_namespace_get_mode_str_stub (BDNVDIMMNamespaceMode mode G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvdimm_namespace_get_mode_str' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvdimm_namespace_get_mode_str' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvdimm_namespace_get_mode_str' called, but not implemented!");
     return NULL;
@@ -133,7 +133,7 @@ const gchar* bd_nvdimm_namespace_get_mode_str (BDNVDIMMNamespaceMode mode, GErro
 
 
 static gchar* bd_nvdimm_namespace_get_devname_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvdimm_namespace_get_devname' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvdimm_namespace_get_devname' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvdimm_namespace_get_devname' called, but not implemented!");
     return NULL;
@@ -158,7 +158,7 @@ gchar* bd_nvdimm_namespace_get_devname (const gchar *device, GError **error) {
 
 
 static gboolean  bd_nvdimm_namespace_enable_stub (const gchar *namespace G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvdimm_namespace_enable' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvdimm_namespace_enable' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvdimm_namespace_enable' called, but not implemented!");
     return FALSE;
@@ -182,7 +182,7 @@ gboolean  bd_nvdimm_namespace_enable (const gchar *namespace, const BDExtraArg *
 
 
 static gboolean  bd_nvdimm_namespace_disable_stub (const gchar *namespace G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvdimm_namespace_disable' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvdimm_namespace_disable' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvdimm_namespace_disable' called, but not implemented!");
     return FALSE;
@@ -206,7 +206,7 @@ gboolean  bd_nvdimm_namespace_disable (const gchar *namespace, const BDExtraArg
 
 
 static BDNVDIMMNamespaceInfo* bd_nvdimm_namespace_info_stub (const gchar *namespace G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvdimm_namespace_info' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvdimm_namespace_info' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvdimm_namespace_info' called, but not implemented!");
     return NULL;
@@ -231,7 +231,7 @@ BDNVDIMMNamespaceInfo* bd_nvdimm_namespace_info (const gchar *namespace, const B
 
 
 static BDNVDIMMNamespaceInfo** bd_nvdimm_list_namespaces_stub (const gchar *bus G_GNUC_UNUSED, const gchar *region G_GNUC_UNUSED, gboolean idle G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvdimm_list_namespaces' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvdimm_list_namespaces' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvdimm_list_namespaces' called, but not implemented!");
     return NULL;
@@ -261,7 +261,7 @@ BDNVDIMMNamespaceInfo** bd_nvdimm_list_namespaces (const gchar *bus, const gchar
 
 
 static gboolean  bd_nvdimm_namespace_reconfigure_stub (const gchar* namespace G_GNUC_UNUSED, BDNVDIMMNamespaceMode mode G_GNUC_UNUSED, gboolean force G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError** error) {
-    g_critical ("The function 'bd_nvdimm_namespace_reconfigure' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvdimm_namespace_reconfigure' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvdimm_namespace_reconfigure' called, but not implemented!");
     return FALSE;
@@ -286,7 +286,7 @@ gboolean  bd_nvdimm_namespace_reconfigure (const gchar* namespace, BDNVDIMMNames
 
 
 static const guint64 * bd_nvdimm_namespace_get_supported_sector_sizes_stub (BDNVDIMMNamespaceMode mode G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_nvdimm_namespace_get_supported_sector_sizes' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_nvdimm_namespace_get_supported_sector_sizes' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_nvdimm_namespace_get_supported_sector_sizes' called, but not implemented!");
     return 0;
