@@ -3,7 +3,7 @@ GQuark  bd_swap_error_quark (void) {
 }
 
 static gboolean  bd_swap_is_tech_avail_stub (BDSwapTech tech G_GNUC_UNUSED, guint64 mode G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_swap_is_tech_avail' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_swap_is_tech_avail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_swap_is_tech_avail' called, but not implemented!");
     return FALSE;
@@ -26,7 +26,7 @@ gboolean  bd_swap_is_tech_avail (BDSwapTech tech, guint64 mode, GError **error)
 
 
 static gboolean  bd_swap_mkswap_stub (const gchar *device G_GNUC_UNUSED, const gchar *label G_GNUC_UNUSED, const gchar *uuid G_GNUC_UNUSED, const BDExtraArg **extra G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_swap_mkswap' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_swap_mkswap' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_swap_mkswap' called, but not implemented!");
     return FALSE;
@@ -53,7 +53,7 @@ gboolean  bd_swap_mkswap (const gchar *device, const gchar *label, const gchar *
 
 
 static gboolean  bd_swap_swapon_stub (const gchar *device G_GNUC_UNUSED, gint priority G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_swap_swapon' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_swap_swapon' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_swap_swapon' called, but not implemented!");
     return FALSE;
@@ -77,7 +77,7 @@ gboolean  bd_swap_swapon (const gchar *device, gint priority, GError **error) {
 
 
 static gboolean  bd_swap_swapoff_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_swap_swapoff' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_swap_swapoff' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_swap_swapoff' called, but not implemented!");
     return FALSE;
@@ -100,7 +100,7 @@ gboolean  bd_swap_swapoff (const gchar *device, GError **error) {
 
 
 static gboolean  bd_swap_swapstatus_stub (const gchar *device G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_swap_swapstatus' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_swap_swapstatus' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_swap_swapstatus' called, but not implemented!");
     return FALSE;
@@ -124,7 +124,7 @@ gboolean  bd_swap_swapstatus (const gchar *device, GError **error) {
 
 
 static gboolean  bd_swap_set_label_stub (const gchar *device G_GNUC_UNUSED, const gchar *label G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_swap_set_label' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_swap_set_label' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_swap_set_label' called, but not implemented!");
     return FALSE;
@@ -148,7 +148,7 @@ gboolean  bd_swap_set_label (const gchar *device, const gchar *label, GError **e
 
 
 static gboolean  bd_swap_set_uuid_stub (const gchar *device G_GNUC_UNUSED, const gchar *uuid G_GNUC_UNUSED, GError **error) {
-    g_critical ("The function 'bd_swap_set_uuid' called, but not implemented!");
+    bd_utils_log_format (BD_UTILS_LOG_CRIT, "The function 'bd_swap_set_uuid' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_swap_set_uuid' called, but not implemented!");
     return FALSE;
